# This is a generated file, use data-scripts/generatePyUniData.py to edit and regenerate.

nameToUnicode = {
    "A": 0x0041,  # LATIN CAPITAL LETTER A
    "AE": 0x00C6,  # LATIN CAPITAL LETTER AE
    "AEacute": 0x01FC,  # LATIN CAPITAL LETTER AE WITH ACUTE
    "Aacute": 0x00C1,  # LATIN CAPITAL LETTER A WITH ACUTE
    "Abreve": 0x0102,  # LATIN CAPITAL LETTER A WITH BREVE
    "Acircumflex": 0x00C2,  # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
    "Adieresis": 0x00C4,  # LATIN CAPITAL LETTER A WITH DIAERESIS
    "Agrave": 0x00C0,  # LATIN CAPITAL LETTER A WITH GRAVE
    "Alpha": 0x0391,  # GREEK CAPITAL LETTER ALPHA
    "Alphatonos": 0x0386,  # GREEK CAPITAL LETTER ALPHA WITH TONOS
    "Amacron": 0x0100,  # LATIN CAPITAL LETTER A WITH MACRON
    "Aogonek": 0x0104,  # LATIN CAPITAL LETTER A WITH OGONEK
    "Aring": 0x00C5,  # LATIN CAPITAL LETTER A WITH RING ABOVE
    "Aringacute": 0x01FA,  # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
    "Atilde": 0x00C3,  # LATIN CAPITAL LETTER A WITH TILDE
    "B": 0x0042,  # LATIN CAPITAL LETTER B
    "Beta": 0x0392,  # GREEK CAPITAL LETTER BETA
    "C": 0x0043,  # LATIN CAPITAL LETTER C
    "Cacute": 0x0106,  # LATIN CAPITAL LETTER C WITH ACUTE
    "Ccaron": 0x010C,  # LATIN CAPITAL LETTER C WITH CARON
    "Ccedilla": 0x00C7,  # LATIN CAPITAL LETTER C WITH CEDILLA
    "Ccircumflex": 0x0108,  # LATIN CAPITAL LETTER C WITH CIRCUMFLEX
    "Cdotaccent": 0x010A,  # LATIN CAPITAL LETTER C WITH DOT ABOVE
    "Chi": 0x03A7,  # GREEK CAPITAL LETTER CHI
    "D": 0x0044,  # LATIN CAPITAL LETTER D
    "Dcaron": 0x010E,  # LATIN CAPITAL LETTER D WITH CARON
    "Dcroat": 0x0110,  # LATIN CAPITAL LETTER D WITH STROKE
    "Delta": 0x2206,  # INCREMENT
    "E": 0x0045,  # LATIN CAPITAL LETTER E
    "Eacute": 0x00C9,  # LATIN CAPITAL LETTER E WITH ACUTE
    "Ebreve": 0x0114,  # LATIN CAPITAL LETTER E WITH BREVE
    "Ecaron": 0x011A,  # LATIN CAPITAL LETTER E WITH CARON
    "Ecircumflex": 0x00CA,  # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
    "Edieresis": 0x00CB,  # LATIN CAPITAL LETTER E WITH DIAERESIS
    "Edotaccent": 0x0116,  # LATIN CAPITAL LETTER E WITH DOT ABOVE
    "Egrave": 0x00C8,  # LATIN CAPITAL LETTER E WITH GRAVE
    "Emacron": 0x0112,  # LATIN CAPITAL LETTER E WITH MACRON
    "Eng": 0x014A,  # LATIN CAPITAL LETTER ENG
    "Eogonek": 0x0118,  # LATIN CAPITAL LETTER E WITH OGONEK
    "Epsilon": 0x0395,  # GREEK CAPITAL LETTER EPSILON
    "Epsilontonos": 0x0388,  # GREEK CAPITAL LETTER EPSILON WITH TONOS
    "Eta": 0x0397,  # GREEK CAPITAL LETTER ETA
    "Etatonos": 0x0389,  # GREEK CAPITAL LETTER ETA WITH TONOS
    "Eth": 0x00D0,  # LATIN CAPITAL LETTER ETH
    "Euro": 0x20AC,  # EURO SIGN
    "F": 0x0046,  # LATIN CAPITAL LETTER F
    "G": 0x0047,  # LATIN CAPITAL LETTER G
    "Gamma": 0x0393,  # GREEK CAPITAL LETTER GAMMA
    "Gbreve": 0x011E,  # LATIN CAPITAL LETTER G WITH BREVE
    "Gcaron": 0x01E6,  # LATIN CAPITAL LETTER G WITH CARON
    "Gcircumflex": 0x011C,  # LATIN CAPITAL LETTER G WITH CIRCUMFLEX
    "Gdotaccent": 0x0120,  # LATIN CAPITAL LETTER G WITH DOT ABOVE
    "H": 0x0048,  # LATIN CAPITAL LETTER H
    "H18533": 0x25CF,  # BLACK CIRCLE
    "H18543": 0x25AA,  # BLACK SMALL SQUARE
    "H18551": 0x25AB,  # WHITE SMALL SQUARE
    "H22073": 0x25A1,  # WHITE SQUARE
    "Hbar": 0x0126,  # LATIN CAPITAL LETTER H WITH STROKE
    "Hcircumflex": 0x0124,  # LATIN CAPITAL LETTER H WITH CIRCUMFLEX
    "I": 0x0049,  # LATIN CAPITAL LETTER I
    "IJ": 0x0132,  # LATIN CAPITAL LIGATURE IJ
    "Iacute": 0x00CD,  # LATIN CAPITAL LETTER I WITH ACUTE
    "Ibreve": 0x012C,  # LATIN CAPITAL LETTER I WITH BREVE
    "Icircumflex": 0x00CE,  # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
    "Idieresis": 0x00CF,  # LATIN CAPITAL LETTER I WITH DIAERESIS
    "Idotaccent": 0x0130,  # LATIN CAPITAL LETTER I WITH DOT ABOVE
    "Ifraktur": 0x2111,  # BLACK-LETTER CAPITAL I
    "Igrave": 0x00CC,  # LATIN CAPITAL LETTER I WITH GRAVE
    "Imacron": 0x012A,  # LATIN CAPITAL LETTER I WITH MACRON
    "Iogonek": 0x012E,  # LATIN CAPITAL LETTER I WITH OGONEK
    "Iota": 0x0399,  # GREEK CAPITAL LETTER IOTA
    "Iotadieresis": 0x03AA,  # GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
    "Iotatonos": 0x038A,  # GREEK CAPITAL LETTER IOTA WITH TONOS
    "Itilde": 0x0128,  # LATIN CAPITAL LETTER I WITH TILDE
    "J": 0x004A,  # LATIN CAPITAL LETTER J
    "Jcircumflex": 0x0134,  # LATIN CAPITAL LETTER J WITH CIRCUMFLEX
    "K": 0x004B,  # LATIN CAPITAL LETTER K
    "Kappa": 0x039A,  # GREEK CAPITAL LETTER KAPPA
    "L": 0x004C,  # LATIN CAPITAL LETTER L
    "Lacute": 0x0139,  # LATIN CAPITAL LETTER L WITH ACUTE
    "Lambda": 0x039B,  # GREEK CAPITAL LETTER LAMDA
    "Lcaron": 0x013D,  # LATIN CAPITAL LETTER L WITH CARON
    "Ldot": 0x013F,  # LATIN CAPITAL LETTER L WITH MIDDLE DOT
    "Lslash": 0x0141,  # LATIN CAPITAL LETTER L WITH STROKE
    "M": 0x004D,  # LATIN CAPITAL LETTER M
    "Mu": 0x039C,  # GREEK CAPITAL LETTER MU
    "N": 0x004E,  # LATIN CAPITAL LETTER N
    "Nacute": 0x0143,  # LATIN CAPITAL LETTER N WITH ACUTE
    "Ncaron": 0x0147,  # LATIN CAPITAL LETTER N WITH CARON
    "Ntilde": 0x00D1,  # LATIN CAPITAL LETTER N WITH TILDE
    "Nu": 0x039D,  # GREEK CAPITAL LETTER NU
    "O": 0x004F,  # LATIN CAPITAL LETTER O
    "OE": 0x0152,  # LATIN CAPITAL LIGATURE OE
    "Oacute": 0x00D3,  # LATIN CAPITAL LETTER O WITH ACUTE
    "Obreve": 0x014E,  # LATIN CAPITAL LETTER O WITH BREVE
    "Ocircumflex": 0x00D4,  # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
    "Odieresis": 0x00D6,  # LATIN CAPITAL LETTER O WITH DIAERESIS
    "Ograve": 0x00D2,  # LATIN CAPITAL LETTER O WITH GRAVE
    "Ohorn": 0x01A0,  # LATIN CAPITAL LETTER O WITH HORN
    "Ohungarumlaut": 0x0150,  # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
    "Omacron": 0x014C,  # LATIN CAPITAL LETTER O WITH MACRON
    "Omega": 0x2126,  # OHM SIGN
    "Omegatonos": 0x038F,  # GREEK CAPITAL LETTER OMEGA WITH TONOS
    "Omicron": 0x039F,  # GREEK CAPITAL LETTER OMICRON
    "Omicrontonos": 0x038C,  # GREEK CAPITAL LETTER OMICRON WITH TONOS
    "Oslash": 0x00D8,  # LATIN CAPITAL LETTER O WITH STROKE
    "Oslashacute": 0x01FE,  # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
    "Otilde": 0x00D5,  # LATIN CAPITAL LETTER O WITH TILDE
    "P": 0x0050,  # LATIN CAPITAL LETTER P
    "Phi": 0x03A6,  # GREEK CAPITAL LETTER PHI
    "Pi": 0x03A0,  # GREEK CAPITAL LETTER PI
    "Psi": 0x03A8,  # GREEK CAPITAL LETTER PSI
    "Q": 0x0051,  # LATIN CAPITAL LETTER Q
    "R": 0x0052,  # LATIN CAPITAL LETTER R
    "Racute": 0x0154,  # LATIN CAPITAL LETTER R WITH ACUTE
    "Rcaron": 0x0158,  # LATIN CAPITAL LETTER R WITH CARON
    "Rfraktur": 0x211C,  # BLACK-LETTER CAPITAL R
    "Rho": 0x03A1,  # GREEK CAPITAL LETTER RHO
    "S": 0x0053,  # LATIN CAPITAL LETTER S
    "SF010000": 0x250C,  # BOX DRAWINGS LIGHT DOWN AND RIGHT
    "SF020000": 0x2514,  # BOX DRAWINGS LIGHT UP AND RIGHT
    "SF030000": 0x2510,  # BOX DRAWINGS LIGHT DOWN AND LEFT
    "SF040000": 0x2518,  # BOX DRAWINGS LIGHT UP AND LEFT
    "SF050000": 0x253C,  # BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
    "SF060000": 0x252C,  # BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
    "SF070000": 0x2534,  # BOX DRAWINGS LIGHT UP AND HORIZONTAL
    "SF080000": 0x251C,  # BOX DRAWINGS LIGHT VERTICAL AND RIGHT
    "SF090000": 0x2524,  # BOX DRAWINGS LIGHT VERTICAL AND LEFT
    "SF100000": 0x2500,  # BOX DRAWINGS LIGHT HORIZONTAL
    "SF110000": 0x2502,  # BOX DRAWINGS LIGHT VERTICAL
    "SF190000": 0x2561,  # BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
    "SF200000": 0x2562,  # BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
    "SF210000": 0x2556,  # BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
    "SF220000": 0x2555,  # BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
    "SF230000": 0x2563,  # BOX DRAWINGS DOUBLE VERTICAL AND LEFT
    "SF240000": 0x2551,  # BOX DRAWINGS DOUBLE VERTICAL
    "SF250000": 0x2557,  # BOX DRAWINGS DOUBLE DOWN AND LEFT
    "SF260000": 0x255D,  # BOX DRAWINGS DOUBLE UP AND LEFT
    "SF270000": 0x255C,  # BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
    "SF280000": 0x255B,  # BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
    "SF360000": 0x255E,  # BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
    "SF370000": 0x255F,  # BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
    "SF380000": 0x255A,  # BOX DRAWINGS DOUBLE UP AND RIGHT
    "SF390000": 0x2554,  # BOX DRAWINGS DOUBLE DOWN AND RIGHT
    "SF400000": 0x2569,  # BOX DRAWINGS DOUBLE UP AND HORIZONTAL
    "SF410000": 0x2566,  # BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
    "SF420000": 0x2560,  # BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
    "SF430000": 0x2550,  # BOX DRAWINGS DOUBLE HORIZONTAL
    "SF440000": 0x256C,  # BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
    "SF450000": 0x2567,  # BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
    "SF460000": 0x2568,  # BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
    "SF470000": 0x2564,  # BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
    "SF480000": 0x2565,  # BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
    "SF490000": 0x2559,  # BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
    "SF500000": 0x2558,  # BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
    "SF510000": 0x2552,  # BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
    "SF520000": 0x2553,  # BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
    "SF530000": 0x256B,  # BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
    "SF540000": 0x256A,  # BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
    "Sacute": 0x015A,  # LATIN CAPITAL LETTER S WITH ACUTE
    "Scaron": 0x0160,  # LATIN CAPITAL LETTER S WITH CARON
    "Scedilla": 0x015E,  # LATIN CAPITAL LETTER S WITH CEDILLA
    "Scircumflex": 0x015C,  # LATIN CAPITAL LETTER S WITH CIRCUMFLEX
    "Sigma": 0x03A3,  # GREEK CAPITAL LETTER SIGMA
    "T": 0x0054,  # LATIN CAPITAL LETTER T
    "Tau": 0x03A4,  # GREEK CAPITAL LETTER TAU
    "Tbar": 0x0166,  # LATIN CAPITAL LETTER T WITH STROKE
    "Tcaron": 0x0164,  # LATIN CAPITAL LETTER T WITH CARON
    "Theta": 0x0398,  # GREEK CAPITAL LETTER THETA
    "Thorn": 0x00DE,  # LATIN CAPITAL LETTER THORN
    "U": 0x0055,  # LATIN CAPITAL LETTER U
    "Uacute": 0x00DA,  # LATIN CAPITAL LETTER U WITH ACUTE
    "Ubreve": 0x016C,  # LATIN CAPITAL LETTER U WITH BREVE
    "Ucircumflex": 0x00DB,  # LATIN CAPITAL LETTER U WITH CIRCUMFLEX
    "Udieresis": 0x00DC,  # LATIN CAPITAL LETTER U WITH DIAERESIS
    "Ugrave": 0x00D9,  # LATIN CAPITAL LETTER U WITH GRAVE
    "Uhorn": 0x01AF,  # LATIN CAPITAL LETTER U WITH HORN
    "Uhungarumlaut": 0x0170,  # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
    "Umacron": 0x016A,  # LATIN CAPITAL LETTER U WITH MACRON
    "Uogonek": 0x0172,  # LATIN CAPITAL LETTER U WITH OGONEK
    "Upsilon": 0x03A5,  # GREEK CAPITAL LETTER UPSILON
    "Upsilon1": 0x03D2,  # GREEK UPSILON WITH HOOK SYMBOL
    "Upsilondieresis": 0x03AB,  # GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
    "Upsilontonos": 0x038E,  # GREEK CAPITAL LETTER UPSILON WITH TONOS
    "Uring": 0x016E,  # LATIN CAPITAL LETTER U WITH RING ABOVE
    "Utilde": 0x0168,  # LATIN CAPITAL LETTER U WITH TILDE
    "V": 0x0056,  # LATIN CAPITAL LETTER V
    "W": 0x0057,  # LATIN CAPITAL LETTER W
    "Wacute": 0x1E82,  # LATIN CAPITAL LETTER W WITH ACUTE
    "Wcircumflex": 0x0174,  # LATIN CAPITAL LETTER W WITH CIRCUMFLEX
    "Wdieresis": 0x1E84,  # LATIN CAPITAL LETTER W WITH DIAERESIS
    "Wgrave": 0x1E80,  # LATIN CAPITAL LETTER W WITH GRAVE
    "X": 0x0058,  # LATIN CAPITAL LETTER X
    "Xi": 0x039E,  # GREEK CAPITAL LETTER XI
    "Y": 0x0059,  # LATIN CAPITAL LETTER Y
    "Yacute": 0x00DD,  # LATIN CAPITAL LETTER Y WITH ACUTE
    "Ycircumflex": 0x0176,  # LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
    "Ydieresis": 0x0178,  # LATIN CAPITAL LETTER Y WITH DIAERESIS
    "Ygrave": 0x1EF2,  # LATIN CAPITAL LETTER Y WITH GRAVE
    "Z": 0x005A,  # LATIN CAPITAL LETTER Z
    "Zacute": 0x0179,  # LATIN CAPITAL LETTER Z WITH ACUTE
    "Zcaron": 0x017D,  # LATIN CAPITAL LETTER Z WITH CARON
    "Zdotaccent": 0x017B,  # LATIN CAPITAL LETTER Z WITH DOT ABOVE
    "Zeta": 0x0396,  # GREEK CAPITAL LETTER ZETA
    "a": 0x0061,  # LATIN SMALL LETTER A
    "aacute": 0x00E1,  # LATIN SMALL LETTER A WITH ACUTE
    "abreve": 0x0103,  # LATIN SMALL LETTER A WITH BREVE
    "acircumflex": 0x00E2,  # LATIN SMALL LETTER A WITH CIRCUMFLEX
    "acute": 0x00B4,  # ACUTE ACCENT
    "acutecomb": 0x0301,  # COMBINING ACUTE ACCENT
    "adieresis": 0x00E4,  # LATIN SMALL LETTER A WITH DIAERESIS
    "ae": 0x00E6,  # LATIN SMALL LETTER AE
    "aeacute": 0x01FD,  # LATIN SMALL LETTER AE WITH ACUTE
    "agrave": 0x00E0,  # LATIN SMALL LETTER A WITH GRAVE
    "aleph": 0x2135,  # ALEF SYMBOL
    "alpha": 0x03B1,  # GREEK SMALL LETTER ALPHA
    "alphatonos": 0x03AC,  # GREEK SMALL LETTER ALPHA WITH TONOS
    "amacron": 0x0101,  # LATIN SMALL LETTER A WITH MACRON
    "ampersand": 0x0026,  # AMPERSAND
    "angle": 0x2220,  # ANGLE
    "angleleft": 0x2329,  # LEFT-POINTING ANGLE BRACKET
    "angleright": 0x232A,  # RIGHT-POINTING ANGLE BRACKET
    "anoteleia": 0x0387,  # GREEK ANO TELEIA
    "aogonek": 0x0105,  # LATIN SMALL LETTER A WITH OGONEK
    "approxequal": 0x2248,  # ALMOST EQUAL TO
    "aring": 0x00E5,  # LATIN SMALL LETTER A WITH RING ABOVE
    "aringacute": 0x01FB,  # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
    "arrowboth": 0x2194,  # LEFT RIGHT ARROW
    "arrowdblboth": 0x21D4,  # LEFT RIGHT DOUBLE ARROW
    "arrowdbldown": 0x21D3,  # DOWNWARDS DOUBLE ARROW
    "arrowdblleft": 0x21D0,  # LEFTWARDS DOUBLE ARROW
    "arrowdblright": 0x21D2,  # RIGHTWARDS DOUBLE ARROW
    "arrowdblup": 0x21D1,  # UPWARDS DOUBLE ARROW
    "arrowdown": 0x2193,  # DOWNWARDS ARROW
    "arrowleft": 0x2190,  # LEFTWARDS ARROW
    "arrowright": 0x2192,  # RIGHTWARDS ARROW
    "arrowup": 0x2191,  # UPWARDS ARROW
    "arrowupdn": 0x2195,  # UP DOWN ARROW
    "arrowupdnbse": 0x21A8,  # UP DOWN ARROW WITH BASE
    "asciicircum": 0x005E,  # CIRCUMFLEX ACCENT
    "asciitilde": 0x007E,  # TILDE
    "asterisk": 0x002A,  # ASTERISK
    "asteriskmath": 0x2217,  # ASTERISK OPERATOR
    "at": 0x0040,  # COMMERCIAL AT
    "atilde": 0x00E3,  # LATIN SMALL LETTER A WITH TILDE
    "b": 0x0062,  # LATIN SMALL LETTER B
    "backslash": 0x005C,  # REVERSE SOLIDUS
    "bar": 0x007C,  # VERTICAL LINE
    "beta": 0x03B2,  # GREEK SMALL LETTER BETA
    "block": 0x2588,  # FULL BLOCK
    "braceleft": 0x007B,  # LEFT CURLY BRACKET
    "braceright": 0x007D,  # RIGHT CURLY BRACKET
    "bracketleft": 0x005B,  # LEFT SQUARE BRACKET
    "bracketright": 0x005D,  # RIGHT SQUARE BRACKET
    "breve": 0x02D8,  # BREVE
    "brokenbar": 0x00A6,  # BROKEN BAR
    "bullet": 0x2022,  # BULLET
    "c": 0x0063,  # LATIN SMALL LETTER C
    "cacute": 0x0107,  # LATIN SMALL LETTER C WITH ACUTE
    "caron": 0x02C7,  # CARON
    "carriagereturn": 0x21B5,  # DOWNWARDS ARROW WITH CORNER LEFTWARDS
    "ccaron": 0x010D,  # LATIN SMALL LETTER C WITH CARON
    "ccedilla": 0x00E7,  # LATIN SMALL LETTER C WITH CEDILLA
    "ccircumflex": 0x0109,  # LATIN SMALL LETTER C WITH CIRCUMFLEX
    "cdotaccent": 0x010B,  # LATIN SMALL LETTER C WITH DOT ABOVE
    "cedilla": 0x00B8,  # CEDILLA
    "cent": 0x00A2,  # CENT SIGN
    "chi": 0x03C7,  # GREEK SMALL LETTER CHI
    "circle": 0x25CB,  # WHITE CIRCLE
    "circlemultiply": 0x2297,  # CIRCLED TIMES
    "circleplus": 0x2295,  # CIRCLED PLUS
    "circumflex": 0x02C6,  # MODIFIER LETTER CIRCUMFLEX ACCENT
    "club": 0x2663,  # BLACK CLUB SUIT
    "colon": 0x003A,  # COLON
    "colonmonetary": 0x20A1,  # COLON SIGN
    "comma": 0x002C,  # COMMA
    "congruent": 0x2245,  # APPROXIMATELY EQUAL TO
    "copyright": 0x00A9,  # COPYRIGHT SIGN
    "currency": 0x00A4,  # CURRENCY SIGN
    "d": 0x0064,  # LATIN SMALL LETTER D
    "dagger": 0x2020,  # DAGGER
    "daggerdbl": 0x2021,  # DOUBLE DAGGER
    "dcaron": 0x010F,  # LATIN SMALL LETTER D WITH CARON
    "dcroat": 0x0111,  # LATIN SMALL LETTER D WITH STROKE
    "degree": 0x00B0,  # DEGREE SIGN
    "delta": 0x03B4,  # GREEK SMALL LETTER DELTA
    "diamond": 0x2666,  # BLACK DIAMOND SUIT
    "dieresis": 0x00A8,  # DIAERESIS
    "dieresistonos": 0x0385,  # GREEK DIALYTIKA TONOS
    "divide": 0x00F7,  # DIVISION SIGN
    "dkshade": 0x2593,  # DARK SHADE
    "dnblock": 0x2584,  # LOWER HALF BLOCK
    "dollar": 0x0024,  # DOLLAR SIGN
    "dong": 0x20AB,  # DONG SIGN
    "dotaccent": 0x02D9,  # DOT ABOVE
    "dotbelowcomb": 0x0323,  # COMBINING DOT BELOW
    "dotlessi": 0x0131,  # LATIN SMALL LETTER DOTLESS I
    "dotmath": 0x22C5,  # DOT OPERATOR
    "e": 0x0065,  # LATIN SMALL LETTER E
    "eacute": 0x00E9,  # LATIN SMALL LETTER E WITH ACUTE
    "ebreve": 0x0115,  # LATIN SMALL LETTER E WITH BREVE
    "ecaron": 0x011B,  # LATIN SMALL LETTER E WITH CARON
    "ecircumflex": 0x00EA,  # LATIN SMALL LETTER E WITH CIRCUMFLEX
    "edieresis": 0x00EB,  # LATIN SMALL LETTER E WITH DIAERESIS
    "edotaccent": 0x0117,  # LATIN SMALL LETTER E WITH DOT ABOVE
    "egrave": 0x00E8,  # LATIN SMALL LETTER E WITH GRAVE
    "eight": 0x0038,  # DIGIT EIGHT
    "element": 0x2208,  # ELEMENT OF
    "ellipsis": 0x2026,  # HORIZONTAL ELLIPSIS
    "emacron": 0x0113,  # LATIN SMALL LETTER E WITH MACRON
    "emdash": 0x2014,  # EM DASH
    "emptyset": 0x2205,  # EMPTY SET
    "endash": 0x2013,  # EN DASH
    "eng": 0x014B,  # LATIN SMALL LETTER ENG
    "eogonek": 0x0119,  # LATIN SMALL LETTER E WITH OGONEK
    "epsilon": 0x03B5,  # GREEK SMALL LETTER EPSILON
    "epsilontonos": 0x03AD,  # GREEK SMALL LETTER EPSILON WITH TONOS
    "equal": 0x003D,  # EQUALS SIGN
    "equivalence": 0x2261,  # IDENTICAL TO
    "estimated": 0x212E,  # ESTIMATED SYMBOL
    "eta": 0x03B7,  # GREEK SMALL LETTER ETA
    "etatonos": 0x03AE,  # GREEK SMALL LETTER ETA WITH TONOS
    "eth": 0x00F0,  # LATIN SMALL LETTER ETH
    "exclam": 0x0021,  # EXCLAMATION MARK
    "exclamdbl": 0x203C,  # DOUBLE EXCLAMATION MARK
    "exclamdown": 0x00A1,  # INVERTED EXCLAMATION MARK
    "existential": 0x2203,  # THERE EXISTS
    "f": 0x0066,  # LATIN SMALL LETTER F
    "female": 0x2640,  # FEMALE SIGN
    "figuredash": 0x2012,  # FIGURE DASH
    "filledbox": 0x25A0,  # BLACK SQUARE
    "filledrect": 0x25AC,  # BLACK RECTANGLE
    "five": 0x0035,  # DIGIT FIVE
    "fiveeighths": 0x215D,  # VULGAR FRACTION FIVE EIGHTHS
    "florin": 0x0192,  # LATIN SMALL LETTER F WITH HOOK
    "four": 0x0034,  # DIGIT FOUR
    "fraction": 0x2044,  # FRACTION SLASH
    "franc": 0x20A3,  # FRENCH FRANC SIGN
    "g": 0x0067,  # LATIN SMALL LETTER G
    "gamma": 0x03B3,  # GREEK SMALL LETTER GAMMA
    "gbreve": 0x011F,  # LATIN SMALL LETTER G WITH BREVE
    "gcaron": 0x01E7,  # LATIN SMALL LETTER G WITH CARON
    "gcircumflex": 0x011D,  # LATIN SMALL LETTER G WITH CIRCUMFLEX
    "gdotaccent": 0x0121,  # LATIN SMALL LETTER G WITH DOT ABOVE
    "germandbls": 0x00DF,  # LATIN SMALL LETTER SHARP S
    "gradient": 0x2207,  # NABLA
    "grave": 0x0060,  # GRAVE ACCENT
    "gravecomb": 0x0300,  # COMBINING GRAVE ACCENT
    "greater": 0x003E,  # GREATER-THAN SIGN
    "greaterequal": 0x2265,  # GREATER-THAN OR EQUAL TO
    "guillemotleft": 0x00AB,  # LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
    "guillemotright": 0x00BB,  # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
    "guilsinglleft": 0x2039,  # SINGLE LEFT-POINTING ANGLE QUOTATION MARK
    "guilsinglright": 0x203A,  # SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
    "h": 0x0068,  # LATIN SMALL LETTER H
    "hbar": 0x0127,  # LATIN SMALL LETTER H WITH STROKE
    "hcircumflex": 0x0125,  # LATIN SMALL LETTER H WITH CIRCUMFLEX
    "heart": 0x2665,  # BLACK HEART SUIT
    "hookabovecomb": 0x0309,  # COMBINING HOOK ABOVE
    "house": 0x2302,  # HOUSE
    "hungarumlaut": 0x02DD,  # DOUBLE ACUTE ACCENT
    "hyphen": 0x002D,  # HYPHEN-MINUS
    "i": 0x0069,  # LATIN SMALL LETTER I
    "iacute": 0x00ED,  # LATIN SMALL LETTER I WITH ACUTE
    "ibreve": 0x012D,  # LATIN SMALL LETTER I WITH BREVE
    "icircumflex": 0x00EE,  # LATIN SMALL LETTER I WITH CIRCUMFLEX
    "idieresis": 0x00EF,  # LATIN SMALL LETTER I WITH DIAERESIS
    "igrave": 0x00EC,  # LATIN SMALL LETTER I WITH GRAVE
    "ij": 0x0133,  # LATIN SMALL LIGATURE IJ
    "imacron": 0x012B,  # LATIN SMALL LETTER I WITH MACRON
    "infinity": 0x221E,  # INFINITY
    "integral": 0x222B,  # INTEGRAL
    "integralbt": 0x2321,  # BOTTOM HALF INTEGRAL
    "integraltp": 0x2320,  # TOP HALF INTEGRAL
    "intersection": 0x2229,  # INTERSECTION
    "invbullet": 0x25D8,  # INVERSE BULLET
    "invcircle": 0x25D9,  # INVERSE WHITE CIRCLE
    "invsmileface": 0x263B,  # BLACK SMILING FACE
    "iogonek": 0x012F,  # LATIN SMALL LETTER I WITH OGONEK
    "iota": 0x03B9,  # GREEK SMALL LETTER IOTA
    "iotadieresis": 0x03CA,  # GREEK SMALL LETTER IOTA WITH DIALYTIKA
    "iotadieresistonos": 0x0390,  # GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
    "iotatonos": 0x03AF,  # GREEK SMALL LETTER IOTA WITH TONOS
    "itilde": 0x0129,  # LATIN SMALL LETTER I WITH TILDE
    "j": 0x006A,  # LATIN SMALL LETTER J
    "jcircumflex": 0x0135,  # LATIN SMALL LETTER J WITH CIRCUMFLEX
    "k": 0x006B,  # LATIN SMALL LETTER K
    "kappa": 0x03BA,  # GREEK SMALL LETTER KAPPA
    "kgreenlandic": 0x0138,  # LATIN SMALL LETTER KRA
    "l": 0x006C,  # LATIN SMALL LETTER L
    "lacute": 0x013A,  # LATIN SMALL LETTER L WITH ACUTE
    "lambda": 0x03BB,  # GREEK SMALL LETTER LAMDA
    "lcaron": 0x013E,  # LATIN SMALL LETTER L WITH CARON
    "ldot": 0x0140,  # LATIN SMALL LETTER L WITH MIDDLE DOT
    "less": 0x003C,  # LESS-THAN SIGN
    "lessequal": 0x2264,  # LESS-THAN OR EQUAL TO
    "lfblock": 0x258C,  # LEFT HALF BLOCK
    "lira": 0x20A4,  # LIRA SIGN
    "logicaland": 0x2227,  # LOGICAL AND
    "logicalnot": 0x00AC,  # NOT SIGN
    "logicalor": 0x2228,  # LOGICAL OR
    "longs": 0x017F,  # LATIN SMALL LETTER LONG S
    "lozenge": 0x25CA,  # LOZENGE
    "lslash": 0x0142,  # LATIN SMALL LETTER L WITH STROKE
    "ltshade": 0x2591,  # LIGHT SHADE
    "m": 0x006D,  # LATIN SMALL LETTER M
    "macron": 0x00AF,  # MACRON
    "male": 0x2642,  # MALE SIGN
    "minus": 0x2212,  # MINUS SIGN
    "minute": 0x2032,  # PRIME
    "mu": 0x00B5,  # MICRO SIGN
    "multiply": 0x00D7,  # MULTIPLICATION SIGN
    "musicalnote": 0x266A,  # EIGHTH NOTE
    "musicalnotedbl": 0x266B,  # BEAMED EIGHTH NOTES
    "n": 0x006E,  # LATIN SMALL LETTER N
    "nacute": 0x0144,  # LATIN SMALL LETTER N WITH ACUTE
    "napostrophe": 0x0149,  # LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
    "ncaron": 0x0148,  # LATIN SMALL LETTER N WITH CARON
    "nine": 0x0039,  # DIGIT NINE
    "notelement": 0x2209,  # NOT AN ELEMENT OF
    "notequal": 0x2260,  # NOT EQUAL TO
    "notsubset": 0x2284,  # NOT A SUBSET OF
    "ntilde": 0x00F1,  # LATIN SMALL LETTER N WITH TILDE
    "nu": 0x03BD,  # GREEK SMALL LETTER NU
    "numbersign": 0x0023,  # NUMBER SIGN
    "o": 0x006F,  # LATIN SMALL LETTER O
    "oacute": 0x00F3,  # LATIN SMALL LETTER O WITH ACUTE
    "obreve": 0x014F,  # LATIN SMALL LETTER O WITH BREVE
    "ocircumflex": 0x00F4,  # LATIN SMALL LETTER O WITH CIRCUMFLEX
    "odieresis": 0x00F6,  # LATIN SMALL LETTER O WITH DIAERESIS
    "oe": 0x0153,  # LATIN SMALL LIGATURE OE
    "ogonek": 0x02DB,  # OGONEK
    "ograve": 0x00F2,  # LATIN SMALL LETTER O WITH GRAVE
    "ohorn": 0x01A1,  # LATIN SMALL LETTER O WITH HORN
    "ohungarumlaut": 0x0151,  # LATIN SMALL LETTER O WITH DOUBLE ACUTE
    "omacron": 0x014D,  # LATIN SMALL LETTER O WITH MACRON
    "omega": 0x03C9,  # GREEK SMALL LETTER OMEGA
    "omega1": 0x03D6,  # GREEK PI SYMBOL
    "omegatonos": 0x03CE,  # GREEK SMALL LETTER OMEGA WITH TONOS
    "omicron": 0x03BF,  # GREEK SMALL LETTER OMICRON
    "omicrontonos": 0x03CC,  # GREEK SMALL LETTER OMICRON WITH TONOS
    "one": 0x0031,  # DIGIT ONE
    "onedotenleader": 0x2024,  # ONE DOT LEADER
    "oneeighth": 0x215B,  # VULGAR FRACTION ONE EIGHTH
    "onehalf": 0x00BD,  # VULGAR FRACTION ONE HALF
    "onequarter": 0x00BC,  # VULGAR FRACTION ONE QUARTER
    "onethird": 0x2153,  # VULGAR FRACTION ONE THIRD
    "openbullet": 0x25E6,  # WHITE BULLET
    "ordfeminine": 0x00AA,  # FEMININE ORDINAL INDICATOR
    "ordmasculine": 0x00BA,  # MASCULINE ORDINAL INDICATOR
    "orthogonal": 0x221F,  # RIGHT ANGLE
    "oslash": 0x00F8,  # LATIN SMALL LETTER O WITH STROKE
    "oslashacute": 0x01FF,  # LATIN SMALL LETTER O WITH STROKE AND ACUTE
    "otilde": 0x00F5,  # LATIN SMALL LETTER O WITH TILDE
    "p": 0x0070,  # LATIN SMALL LETTER P
    "paragraph": 0x00B6,  # PILCROW SIGN
    "parenleft": 0x0028,  # LEFT PARENTHESIS
    "parenright": 0x0029,  # RIGHT PARENTHESIS
    "partialdiff": 0x2202,  # PARTIAL DIFFERENTIAL
    "percent": 0x0025,  # PERCENT SIGN
    "period": 0x002E,  # FULL STOP
    "periodcentered": 0x00B7,  # MIDDLE DOT
    "perpendicular": 0x22A5,  # UP TACK
    "perthousand": 0x2030,  # PER MILLE SIGN
    "peseta": 0x20A7,  # PESETA SIGN
    "phi": 0x03C6,  # GREEK SMALL LETTER PHI
    "phi1": 0x03D5,  # GREEK PHI SYMBOL
    "pi": 0x03C0,  # GREEK SMALL LETTER PI
    "plus": 0x002B,  # PLUS SIGN
    "plusminus": 0x00B1,  # PLUS-MINUS SIGN
    "prescription": 0x211E,  # PRESCRIPTION TAKE
    "product": 0x220F,  # N-ARY PRODUCT
    "propersubset": 0x2282,  # SUBSET OF
    "propersuperset": 0x2283,  # SUPERSET OF
    "proportional": 0x221D,  # PROPORTIONAL TO
    "psi": 0x03C8,  # GREEK SMALL LETTER PSI
    "q": 0x0071,  # LATIN SMALL LETTER Q
    "question": 0x003F,  # QUESTION MARK
    "questiondown": 0x00BF,  # INVERTED QUESTION MARK
    "quotedbl": 0x0022,  # QUOTATION MARK
    "quotedblbase": 0x201E,  # DOUBLE LOW-9 QUOTATION MARK
    "quotedblleft": 0x201C,  # LEFT DOUBLE QUOTATION MARK
    "quotedblright": 0x201D,  # RIGHT DOUBLE QUOTATION MARK
    "quoteleft": 0x2018,  # LEFT SINGLE QUOTATION MARK
    "quotereversed": 0x201B,  # SINGLE HIGH-REVERSED-9 QUOTATION MARK
    "quoteright": 0x2019,  # RIGHT SINGLE QUOTATION MARK
    "quotesinglbase": 0x201A,  # SINGLE LOW-9 QUOTATION MARK
    "quotesingle": 0x0027,  # APOSTROPHE
    "r": 0x0072,  # LATIN SMALL LETTER R
    "racute": 0x0155,  # LATIN SMALL LETTER R WITH ACUTE
    "radical": 0x221A,  # SQUARE ROOT
    "rcaron": 0x0159,  # LATIN SMALL LETTER R WITH CARON
    "reflexsubset": 0x2286,  # SUBSET OF OR EQUAL TO
    "reflexsuperset": 0x2287,  # SUPERSET OF OR EQUAL TO
    "registered": 0x00AE,  # REGISTERED SIGN
    "revlogicalnot": 0x2310,  # REVERSED NOT SIGN
    "rho": 0x03C1,  # GREEK SMALL LETTER RHO
    "ring": 0x02DA,  # RING ABOVE
    "rtblock": 0x2590,  # RIGHT HALF BLOCK
    "s": 0x0073,  # LATIN SMALL LETTER S
    "sacute": 0x015B,  # LATIN SMALL LETTER S WITH ACUTE
    "scaron": 0x0161,  # LATIN SMALL LETTER S WITH CARON
    "scedilla": 0x015F,  # LATIN SMALL LETTER S WITH CEDILLA
    "scircumflex": 0x015D,  # LATIN SMALL LETTER S WITH CIRCUMFLEX
    "second": 0x2033,  # DOUBLE PRIME
    "section": 0x00A7,  # SECTION SIGN
    "semicolon": 0x003B,  # SEMICOLON
    "seven": 0x0037,  # DIGIT SEVEN
    "seveneighths": 0x215E,  # VULGAR FRACTION SEVEN EIGHTHS
    "shade": 0x2592,  # MEDIUM SHADE
    "sigma": 0x03C3,  # GREEK SMALL LETTER SIGMA
    "sigma1": 0x03C2,  # GREEK SMALL LETTER FINAL SIGMA
    "similar": 0x223C,  # TILDE OPERATOR
    "six": 0x0036,  # DIGIT SIX
    "slash": 0x002F,  # SOLIDUS
    "smileface": 0x263A,  # WHITE SMILING FACE
    "space": 0x0020,  # SPACE
    "spade": 0x2660,  # BLACK SPADE SUIT
    "sterling": 0x00A3,  # POUND SIGN
    "suchthat": 0x220B,  # CONTAINS AS MEMBER
    "summation": 0x2211,  # N-ARY SUMMATION
    "sun": 0x263C,  # WHITE SUN WITH RAYS
    "t": 0x0074,  # LATIN SMALL LETTER T
    "tau": 0x03C4,  # GREEK SMALL LETTER TAU
    "tbar": 0x0167,  # LATIN SMALL LETTER T WITH STROKE
    "tcaron": 0x0165,  # LATIN SMALL LETTER T WITH CARON
    "therefore": 0x2234,  # THEREFORE
    "theta": 0x03B8,  # GREEK SMALL LETTER THETA
    "theta1": 0x03D1,  # GREEK THETA SYMBOL
    "thorn": 0x00FE,  # LATIN SMALL LETTER THORN
    "three": 0x0033,  # DIGIT THREE
    "threeeighths": 0x215C,  # VULGAR FRACTION THREE EIGHTHS
    "threequarters": 0x00BE,  # VULGAR FRACTION THREE QUARTERS
    "tilde": 0x02DC,  # SMALL TILDE
    "tildecomb": 0x0303,  # COMBINING TILDE
    "tonos": 0x0384,  # GREEK TONOS
    "trademark": 0x2122,  # TRADE MARK SIGN
    "triagdn": 0x25BC,  # BLACK DOWN-POINTING TRIANGLE
    "triaglf": 0x25C4,  # BLACK LEFT-POINTING POINTER
    "triagrt": 0x25BA,  # BLACK RIGHT-POINTING POINTER
    "triagup": 0x25B2,  # BLACK UP-POINTING TRIANGLE
    "two": 0x0032,  # DIGIT TWO
    "twodotenleader": 0x2025,  # TWO DOT LEADER
    "twothirds": 0x2154,  # VULGAR FRACTION TWO THIRDS
    "u": 0x0075,  # LATIN SMALL LETTER U
    "uacute": 0x00FA,  # LATIN SMALL LETTER U WITH ACUTE
    "ubreve": 0x016D,  # LATIN SMALL LETTER U WITH BREVE
    "ucircumflex": 0x00FB,  # LATIN SMALL LETTER U WITH CIRCUMFLEX
    "udieresis": 0x00FC,  # LATIN SMALL LETTER U WITH DIAERESIS
    "ugrave": 0x00F9,  # LATIN SMALL LETTER U WITH GRAVE
    "uhorn": 0x01B0,  # LATIN SMALL LETTER U WITH HORN
    "uhungarumlaut": 0x0171,  # LATIN SMALL LETTER U WITH DOUBLE ACUTE
    "umacron": 0x016B,  # LATIN SMALL LETTER U WITH MACRON
    "underscore": 0x005F,  # LOW LINE
    "underscoredbl": 0x2017,  # DOUBLE LOW LINE
    "union": 0x222A,  # UNION
    "universal": 0x2200,  # FOR ALL
    "uogonek": 0x0173,  # LATIN SMALL LETTER U WITH OGONEK
    "upblock": 0x2580,  # UPPER HALF BLOCK
    "upsilon": 0x03C5,  # GREEK SMALL LETTER UPSILON
    "upsilondieresis": 0x03CB,  # GREEK SMALL LETTER UPSILON WITH DIALYTIKA
    "upsilondieresistonos": 0x03B0,  # GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
    "upsilontonos": 0x03CD,  # GREEK SMALL LETTER UPSILON WITH TONOS
    "uring": 0x016F,  # LATIN SMALL LETTER U WITH RING ABOVE
    "utilde": 0x0169,  # LATIN SMALL LETTER U WITH TILDE
    "v": 0x0076,  # LATIN SMALL LETTER V
    "w": 0x0077,  # LATIN SMALL LETTER W
    "wacute": 0x1E83,  # LATIN SMALL LETTER W WITH ACUTE
    "wcircumflex": 0x0175,  # LATIN SMALL LETTER W WITH CIRCUMFLEX
    "wdieresis": 0x1E85,  # LATIN SMALL LETTER W WITH DIAERESIS
    "weierstrass": 0x2118,  # SCRIPT CAPITAL P
    "wgrave": 0x1E81,  # LATIN SMALL LETTER W WITH GRAVE
    "x": 0x0078,  # LATIN SMALL LETTER X
    "xi": 0x03BE,  # GREEK SMALL LETTER XI
    "y": 0x0079,  # LATIN SMALL LETTER Y
    "yacute": 0x00FD,  # LATIN SMALL LETTER Y WITH ACUTE
    "ycircumflex": 0x0177,  # LATIN SMALL LETTER Y WITH CIRCUMFLEX
    "ydieresis": 0x00FF,  # LATIN SMALL LETTER Y WITH DIAERESIS
    "yen": 0x00A5,  # YEN SIGN
    "ygrave": 0x1EF3,  # LATIN SMALL LETTER Y WITH GRAVE
    "z": 0x007A,  # LATIN SMALL LETTER Z
    "zacute": 0x017A,  # LATIN SMALL LETTER Z WITH ACUTE
    "zcaron": 0x017E,  # LATIN SMALL LETTER Z WITH CARON
    "zdotaccent": 0x017C,  # LATIN SMALL LETTER Z WITH DOT ABOVE
    "zero": 0x0030,  # DIGIT ZERO
    "zeta": 0x03B6,  # GREEK SMALL LETTER ZETA
    # Local additions:
    "CR": 0x000D,
    "NULL": 0x0000,
    "fi": 0xFB01,
    "fl": 0xFB02,
    "onesuperior": 0x00B9,
    "threesuperior": 0x00B3,
    "twosuperior": 0x00B2,
}
